_xmlSAXLocator

Struct _xmlSAXLocator 

#[repr(C)]
pub struct _xmlSAXLocator { pub getPublicId: Option<unsafe extern "C" fn(ctx: *mut c_void) -> *const xmlChar>, pub getSystemId: Option<unsafe extern "C" fn(ctx: *mut c_void) -> *const xmlChar>, pub getLineNumber: Option<unsafe extern "C" fn(ctx: *mut c_void) -> c_int>, pub getColumnNumber: Option<unsafe extern "C" fn(ctx: *mut c_void) -> c_int>, }
The SAX locator structure providing line/column information.

UPSTREAM-PARITY

This is an opaque structure from the perspective of SAX handlers. Upstream defines it as:

typedef struct _xmlSAXLocator xmlSAXLocator;
typedef xmlSAXLocator *xmlSAXLocatorPtr;
struct _xmlSAXLocator {
    xmlChar *(*getPublicId)(void *ctx);
    xmlChar *(*getSystemId)(void *ctx);
    int      (*getLineNumber)(void *ctx);
    int      (*getColumnNumber)(void *ctx);
};

Fields

getPublicId: Option<unsafe extern "C" fn(ctx: *mut c_void) -> *const xmlChar>

Get the public ID of the current document position.

getSystemId: Option<unsafe extern "C" fn(ctx: *mut c_void) -> *const xmlChar>

Get the system ID of the current document position.

getLineNumber: Option<unsafe extern "C" fn(ctx: *mut c_void) -> c_int>

Get the line number of the current document position.

getColumnNumber: Option<unsafe extern "C" fn(ctx: *mut c_void) -> c_int>

Get the column number of the current document position.