xmlHashDeallocator

Type Alias xmlHashDeallocator 

pub type xmlHashDeallocator = unsafe extern "C" fn(payload: *mut c_void, name: *mut xmlChar);
Deallocator function for hash table entries.

Called when removing an entry from a hash table. The function receives the payload and the name (key) of the entry.