xmlBufferResize

Function xmlBufferResize 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlBufferResize( buf: *mut _xmlBuffer, size: c_uint, ) -> c_int
Resize a buffer to a minimum size.

UPSTREAM-PARITY

int xmlBufferResize(xmlBuffer *buf, unsigned int size);

buf.c 2.15: returns 0 when buf is NULL, 1 when size is below the current capacity, otherwise grows the buffer so its total capacity is at least size and returns 1 on success / 0 on allocation failure.

SAFETY

  • buf must be a valid pointer to a _xmlBuffer (or NULL).