xmlStrstr

Function xmlStrstr 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlStrstr( str: *const xmlChar, val: *const xmlChar, ) -> *const xmlChar
Find the first occurrence of val in str (upstream xmlstring.c xmlStrstr).

UPSTREAM-PARITY

const xmlChar *xmlStrstr(const xmlChar *str, const xmlChar *val);

Returns a pointer to the first occurrence, str itself when val is empty, or NULL when not found / either argument is NULL.

SAFETY

  • str and val must be valid null-terminated byte strings or NULL.