xmlXIncludeProcessTreeFlagsData

Function xmlXIncludeProcessTreeFlagsData 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlXIncludeProcessTreeFlagsData( tree: *mut _xmlNode, flags: c_int, data: *mut c_void, ) -> c_int
Process all XInclude nodes in the document containing tree, with flags and an error-handler data pointer.

Returns the number of XInclude nodes processed, or -1 on error.

UPSTREAM-PARITY

int xmlXIncludeProcessTreeFlagsData(xmlNode *tree, int flags, void *data);

SAFETY

tree must be NULL or a valid _xmlNode attached to a document; data must be NULL or a valid pointer for the lifetime of the call.