xmlGetLastError

Function xmlGetLastError 

#[unsafe(no_mangle)]
pub extern "C" fn xmlGetLastError() -> *mut _xmlError
Get the last error for the current thread.

UPSTREAM-PARITY

xmlErrorPtr xmlGetLastError(void);

Returns a pointer to the last error, or NULL if no error occurred. The returned pointer is valid until the next libxml2 call in this thread.