xmlRaiseError

Function xmlRaiseError 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlRaiseError( ctxt: *mut c_void, ctxt2: *mut c_void, ctxt3: *mut c_void, ctxt4: *mut c_void, ctxt5: *mut c_void, domain: c_int, code: c_int, level: c_int, file: *const c_char, line: c_int, str1: *const c_char, str2: *const c_char, str3: *const c_char, int1: c_int, int2: c_int, msg: *const c_char, )
Raise a structured error.

This is called internally when an error occurs. It updates the last error and invokes the structured error handler if one is set.

SAFETY

  • ctxt may be NULL (context of the error).
  • domain, code, level: valid error codes.
  • msg must be a valid C string or NULL.
  • file must be a valid C string or NULL.
  • str1, str2, str3: error-related strings (may be NULL).