xmlSetGenericErrorFunc

Function xmlSetGenericErrorFunc 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlSetGenericErrorFunc( ctx: *mut c_void, handler: Option<xmlGenericErrorFunc>, )
Set the generic error handler.

UPSTREAM-PARITY

void xmlSetGenericErrorFunc(void *ctx, xmlGenericErrorFunc handler);

SAFETY

  • handler must be a valid function pointer or NULL (to reset to default).
  • If non-NULL, the handler may be called at any time with ctx.