Version compatibility profiles (68, 85 Phase 11).
Version-aware profiles that allow libxml-rs to emulate the behavior of specific historical upstream versions.
Phase 0: scaffolded.
Version compatibility profiles (68, 85 Phase 11).
Version-aware profiles that allow libxml-rs to emulate the behavior of specific historical upstream versions.
Phase 0: scaffolded.