Automata/state machine infrastructure (85 Phase 7).
libxml2’s internal automata implementation used by the regex engine and schema validation.
Phase 0: scaffolded. Implementation begins in Phase 7.
Automata/state machine infrastructure (85 Phase 7).
libxml2’s internal automata implementation used by the regex engine and schema validation.
Phase 0: scaffolded. Implementation begins in Phase 7.