xmlAutomataCompile

Function xmlAutomataCompile 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlAutomataCompile( am: XmlAutomataPtr, ) -> c_int
Compile the automata into a regex.

UPSTREAM-PARITY: xmlAutomataCompile()

This builds a regex pattern string from the automata’s state machine and compiles it using the regex engine.