dict_free

Function dict_free 

pub unsafe fn dict_free(dict: *mut Dict)
Free a dictionary and all its interned strings.

UPSTREAM-PARITY

void xmlDictFree(xmlDictPtr dict);

SAFETY

  • dict must be a valid pointer to a Dict, or NULL.
  • After this call, any strings obtained from the dictionary become invalid.