get_attribute_decl

Function get_attribute_decl 

pub unsafe fn get_attribute_decl(
    dtd: *mut _xmlDtd,
    elem: *mut _xmlElement,
    name: *const xmlChar,
    _namePrefix: c_int,
) -> *mut _xmlAttribute
Look up an attribute declaration by element name and attribute name.

UPSTREAM-PARITY

xmlAttributePtr xmlGetAttributeDecl(xmlDtdPtr dtd, xmlElementPtr elem,
                                    const xmlChar *name, int namePrefix);

The namePrefix parameter is ignored in this implementation (it’s a legacy parameter in libxml2).

SAFETY

  • dtd must be a valid pointer to an _xmlDtd, or NULL.
  • name must be a valid null-terminated string.
  • elem may be NULL.