Module entities

Module entities 

Entity handling (24, 85 Phase 6).

General entities, parameter entities, external entities, entity substitution, entity references, security limits, recursive entities, expansion limits.

Constants

XML_ENTITY_CONTENT_DEPTH_MAX
Maximum entity recursion depth.
XML_ENTITY_CONTENT_EXPANSION_MAX
Maximum entity expansion size (in bytes).

Functions

add_entity
Add an entity declaration to a DTD.
check_entity_expansion_limit
Check if entity expansion exceeds limits.
check_entity_recursion_depth
Check if entity recursion depth exceeds limits.
copy_entity
Deep copy an entity declaration.
encode_entities_reentrant
Encode special XML characters in a string for output.
free_entity
Free an entity declaration.
get_entity
Get a general entity by name.
get_entity_content
Get the content of an entity as a string.
get_entity_from_dtd
Look up an entity in a DTD’s entity hash table (upstream xmlGetDtdEntity core).
get_parameter_entity
Get a parameter entity by name.
is_external_entity
Check if an entity type is an external entity.
is_parameter_entity
Check if an entity type is a parameter entity.
is_predefined_entity
Check if an entity type is a predefined entity.
string_decode_entities
Decode entity references in a string.