get_parameter_entity

Function get_parameter_entity 

pub unsafe fn get_parameter_entity(
    doc: *mut _xmlDoc,
    name: *const xmlChar,
) -> *mut _xmlEntity
Get a parameter entity by name.

UPSTREAM-PARITY

xmlEntityPtr xmlGetParameterEntity(xmlDocPtr doc, const xmlChar *name);

Searches the document’s DTD for a parameter entity with the given name.

SAFETY

  • doc must be a valid pointer to an _xmlDoc, or NULL.
  • name must be a valid null-terminated string.