parser_delivery

Function parser_delivery 

pub unsafe fn parser_delivery(ctxt: *mut _xmlParserCtxt) -> GenericDelivery
Select the generic delivery for a parser error from the context’s SAX error slot (upstream xmlCtxtVErr: channel = ctxt->sax->error). Used by the parser layer and by the SAX-layer depth error (HOSTILE-FAILURE F1).

Safety

  • ctxt must be a valid _xmlParserCtxt with a valid sax pointer.