cleanup_parser

Function cleanup_parser 

pub unsafe fn cleanup_parser()
Clean up the parser library.

Should be called when the library is no longer needed. Only performs actual cleanup when the reference count reaches zero.

SAFETY

Must not be called while other libxml2 functions are executing in any thread.