get_last_error

Function get_last_error 

pub fn get_last_error() -> *mut _xmlError
Get the last error for this thread.

Returns a mutable pointer to the last error, or NULL if no error occurred. The returned pointer is valid until the next libxml2 call in this thread.