set_generic_error_func

Function set_generic_error_func 

pub unsafe fn set_generic_error_func(
    ctx: *mut c_void,
    handler: Option<xmlGenericErrorFunc>,
)
Set the generic error handler.

SAFETY

  • handler must be a valid function pointer or NULL (to reset to default).
  • If non-NULL, the handler may be called at any time with ctx.