hash_copy

Function hash_copy 

pub unsafe fn hash_copy(
    table: *mut HashTable,
    f: Option<xmlHashCopier>,
) -> *mut HashTable
Copy a hash table.

UPSTREAM-PARITY

xmlHashTablePtr xmlHashCopy(xmlHashTablePtr table, xmlHashCopier f);

Creates a new hash table with copied entries. The f function is called for each entry to create a copy of the payload.

Returns the new hash table, or NULL on failure.

SAFETY

  • table must be a valid pointer to a HashTable, or NULL.
  • f may be NULL (payloads are copied by pointer).