hash_create_dict

Function hash_create_dict 

pub fn hash_create_dict(size: c_int, _dict: *mut c_void) -> *mut HashTable
Create a hash table with dictionary-backed keys.

UPSTREAM-PARITY

xmlHashTablePtr xmlHashCreateDict(int size, xmlDictPtr dict);

Creates a hash table where keys are interned in the given dictionary. The dictionary reference is stored but in this implementation, keys are still stored as raw pointers for simplicity.