hash_scan

Function hash_scan 

pub unsafe fn hash_scan(
    table: *mut HashTable,
    f: Option<xmlHashScanner>,
    data: *mut c_void,
)
Scan all entries with a scanner function.

UPSTREAM-PARITY

void xmlHashScan(xmlHashTablePtr table, xmlHashScanner f, void *data);

SAFETY

  • table must be a valid pointer to a HashTable, or NULL.
  • f must be a valid function pointer or NULL.
  • data may be NULL.