xmlReaderForMemory

Function xmlReaderForMemory 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlReaderForMemory( buffer: *const c_char, size: c_int, URL: *const c_char, encoding: *const c_char, options: c_int, ) -> *mut XmlTextReader
Create a text reader from memory.

UPSTREAM-PARITY

xmlTextReaderPtr xmlReaderForMemory(const char *buffer, int size,
                                    const char *URL, const char *encoding, int options);

Safety

  • buffer must be a valid pointer with at least size readable bytes.
  • URL and encoding must be valid C strings or NULL.