xmlTextReaderRead

Function xmlTextReaderRead 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlTextReaderRead( reader: *mut XmlTextReader, ) -> c_int
Advance the reader to the next node in document order.

Returns 1 on success, 0 if EOF, -1 on error.

UPSTREAM-PARITY

int xmlTextReaderRead(xmlTextReaderPtr reader);

Safety

reader must be a valid pointer returned by xmlNewTextReader or one of the xmlReaderFor* functions, or NULL (in which case -1 is returned).