build_qname

Function build_qname 

pub unsafe fn build_qname(
    ncname: *const xmlChar,
    prefix: *const xmlChar,
    memory: *mut xmlChar,
    len: c_int,
) -> *mut xmlChar
Build a QName prefix:local (upstream tree.c xmlBuildQName): writes into memory when it is large enough, otherwise allocates. Returns the resulting string (allocator-owned when not memory), or NULL on error. A NULL prefix returns ncname unchanged.

Safety

  • ncname, prefix must be valid null-terminated strings or NULL.
  • memory must be a valid buffer of len bytes or NULL.