Function remove_prop
Source pub unsafe fn remove_prop(attr: *mut _xmlAttr) -> c_int
Remove a property from a node.
UPSTREAM-PARITY
int xmlRemoveProp(xmlAttrPtr attr);
Removes the attribute from its parent node and frees it.
Returns 0 on success, -1 on failure.
SAFETY
attr must be a valid pointer to an _xmlAttr, or NULL.