search_ns

Function search_ns 

pub unsafe fn search_ns(
    doc: *mut _xmlDoc,
    node: *mut _xmlNode,
    name_space: *const xmlChar,
) -> *mut _xmlNs
Search for a namespace by prefix.

UPSTREAM-PARITY

xmlNsPtr xmlSearchNs(xmlDocPtr doc, xmlNodePtr node, const xmlChar *nameSpace);

Searches for a namespace declaration with the given prefix. If nameSpace is NULL, searches for the default namespace.

SAFETY

  • doc must be a valid pointer to an _xmlDoc, or NULL.
  • node must be a valid pointer to an _xmlNode, or NULL.
  • nameSpace must be a valid null-terminated string or NULL.