is_mixed_element

Function is_mixed_element 

pub unsafe fn is_mixed_element(doc: *mut _xmlDoc, name: *const xmlChar) -> c_int
Check if an element has a mixed content model.

UPSTREAM-PARITY

int xmlIsMixedElement(xmlDocPtr doc, const xmlChar *name);

Returns 1 if the element is declared as mixed content, 0 otherwise.

SAFETY

  • doc, name may be NULL.