xmlNewTextWriterTree

Function xmlNewTextWriterTree 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlNewTextWriterTree( doc: *mut _xmlDoc, node: *mut _xmlNode, compression: c_int, ) -> *mut XmlTextWriter
Create a new XML text writer for a subtree.

UPSTREAM-PARITY

xmlTextWriterPtr xmlNewTextWriterTree(xmlDocPtr doc, xmlNodePtr node, int compression);

SAFETY

  • doc must be a valid pointer to an _xmlDoc or NULL.
  • node must be a valid pointer to an _xmlNode or NULL.