xmlTextWriterEndDocument

Function xmlTextWriterEndDocument 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlTextWriterEndDocument( writer: *mut XmlTextWriter, ) -> c_int
End an XML document.

Flushes any pending output and writes a final newline if indentation is enabled.

UPSTREAM-PARITY

int xmlTextWriterEndDocument(xmlTextWriterPtr writer);

SAFETY

  • writer must be a valid pointer to an XmlTextWriter or NULL.