xmlTextWriterStartAttribute

Function xmlTextWriterStartAttribute 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlTextWriterStartAttribute( writer: *mut XmlTextWriter, name: *const xmlChar, ) -> c_int
Write a formatted attribute.

UPSTREAM-PARITY

int xmlTextWriterWriteFormatAttribute(xmlTextWriterPtr writer,
                                       const xmlChar *name,
                                       ...);

SAFETY

  • writer must be a valid pointer to an XmlTextWriter or NULL.
  • name must be a valid null-terminated string. Start an attribute (to be written incrementally).

UPSTREAM-PARITY

int xmlTextWriterStartAttribute(xmlTextWriterPtr writer, const xmlChar *name);

SAFETY

  • writer must be a valid pointer to an XmlTextWriter or NULL.
  • name must be a valid null-terminated string or NULL.