xmlTextWriterWriteBase64

Function xmlTextWriterWriteBase64 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlTextWriterWriteBase64( writer: *mut XmlTextWriter, data: *const c_char, start: c_int, len: c_int, ) -> c_int
Write a formatted string.

UPSTREAM-PARITY

int xmlTextWriterWriteFormatString(xmlTextWriterPtr writer, const char *fmt, ...);

SAFETY

  • writer must be a valid pointer to an XmlTextWriter or NULL.

Write Base64-encoded data.

UPSTREAM-PARITY

int xmlTextWriterWriteBase64(xmlTextWriterPtr writer,
                              const char *data,
                              int start,
                              int len);

SAFETY

  • writer must be a valid pointer to an XmlTextWriter or NULL.
  • data must be a valid pointer to start + len bytes or NULL.