Function xmlTextWriterWriteRawLen
Source #[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlTextWriterWriteRawLen(
writer: *mut XmlTextWriter,
content: *const xmlChar,
len: c_int,
) -> c_int
Write raw content with explicit length (no XML escaping).
UPSTREAM-PARITY
int xmlTextWriterWriteRawLen(xmlTextWriterPtr writer,
const xmlChar *content,
int len);
SAFETY
writer must be a valid pointer to an XmlTextWriter or NULL.
content must point to len valid bytes or NULL.