xmlXPathNewValueTree

Function xmlXPathNewValueTree 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlXPathNewValueTree( val: *mut _xmlNode, ) -> *mut _xmlXPathObject
xmlXPathObjectPtr xmlXPathNewValueTree(xmlNodePtr val) โ€” a node-set object containing a single node whose subtree is owned by the object.

SAFETY

  • val must be a valid node pointer or NULL.