Token

Enum Token 

pub enum Token {
Show 46 variants Name(String), Star, Dot, DotDot, At, DoubleColon, Slash, DoubleSlash, Pipe, Plus, Minus, Eq, Ne, Lt, Gt, Le, Ge, Multiply, Or, And, Mod, Div, Ancestor, AncestorOrSelf, Attribute, Child, Descendant, DescendantOrSelf, Following, FollowingSibling, Namespace, Parent, Preceding, PrecedingSibling, Self_, StringLiteral(String), NumberLiteral(f64), LParen, RParen, LBracket, RBracket, LBrace, RBrace, Comma, Dollar, Eof,
}

Variants



Name(String)

Name (NCName or QName)



Star

* wildcard



Dot

. (self)



DotDot

.. (parent)



At

@ (attribute axis)



DoubleColon

:: (axis separator)



Slash

/



DoubleSlash

//



Pipe

|



Plus

+



Minus

-



Eq

=



Ne

!=



Lt

<



Gt

>



Le

<=



Ge

>=



Multiply

* (multiplication operator, distinct from wildcard)



Or

or



And

and



Mod

mod



Div

div



Ancestor

ancestor



AncestorOrSelf

ancestor-or-self



Attribute

attribute



Child

child



Descendant

descendant



DescendantOrSelf

descendant-or-self



Following

following



FollowingSibling

following-sibling



Namespace

namespace



Parent

parent



Preceding

preceding



PrecedingSibling

preceding-sibling



Self_

self



StringLiteral(String)

String literal (without quotes)



NumberLiteral(f64)

Numeric literal



LParen



RParen



LBracket



RBracket



LBrace



RBrace



Comma



Dollar

$ (variable reference)



Eof

End of expression