pop_number

Function pop_number 

pub unsafe fn pop_number(pc: *mut XmlXPathParserContext) -> f64
Pop a number (upstream xmlXPathPopNumber): converts the top of the stack to a number, frees it, returns the value.

SAFETY

  • pc must be a valid parser context or NULL.