xsltSortNodeSet

Function xsltSortNodeSet 

pub unsafe fn xsltSortNodeSet(
    ctxt: *mut _xsltTransformContext,
    nodes: *mut _xmlNodeSet,
    sorts: *mut _xsltSort,
)
Sort a node-set according to the sort specifications.

nodes is the node-set to sort (modified in place). sorts is a linked list of sort specifications (first = primary key).

SAFETY

  • ctxt must be a valid _xsltTransformContext.
  • nodes must be a valid _xmlNodeSet.
  • sorts must be a valid linked list of _xsltSort.