xmlMemoryDump

Function xmlMemoryDump 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlMemoryDump() -> c_int
Dump memory allocation statistics (upstream xmlmemory.h).

int xmlMemoryDump(void);

Prints the global counters to stderr and returns 0 (no leak detector is active in the default allocator).