#[unsafe(no_mangle)]pub unsafe extern "C" fn htmlGetMetaEncoding(
doc: *mut _xmlDoc,
) -> *const xmlCharExpand description
Look up an encoding declaration in the meta tags of the document.
The returned string points into attribute content (may contain trailing garbage); it should be copied before modifying or freeing nodes — upstream contract.
UPSTREAM-PARITY
const xmlChar *htmlGetMetaEncoding(xmlDoc *doc);