#[unsafe(no_mangle)]pub unsafe extern "C" fn xmlXIncludeProcessNode(
ctxt: xmlXIncludeCtxtPtr,
tree: *mut _xmlNode,
) -> c_intExpand description
Process the XInclude nodes in the tree rooted at tree, using the
context’s document and flags.
Returns the number of XInclude nodes processed, or -1 on error.
UPSTREAM-PARITY
int xmlXIncludeProcessNode(xmlXIncludeCtxt *ctxt, xmlNode *tree);SAFETY
ctxt must be a valid context created by xmlXIncludeNewContext; tree
must be NULL or a valid _xmlNode.