#[unsafe(no_mangle)]pub unsafe extern "C" fn xmlXIncludeSetErrorHandler(
ctxt: xmlXIncludeCtxtPtr,
handler: Option<xmlXIncludeErrorFunc>,
data: *mut c_void,
)Expand description
Set the error handler and its data on the context.
UPSTREAM-PARITY
void xmlXIncludeSetErrorHandler(xmlXIncludeCtxt *ctxt,
xmlXIncludeErrorFunc handler,
void *data);SAFETY
ctxt must be NULL or a valid context created by xmlXIncludeNewContext;
data must be NULL or a valid pointer for as long as the handler may be
called.