Function xmlCopyError
Source #[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlCopyError(
from: *const _xmlError,
to: *mut _xmlError,
) -> c_int
Get a copy of the last error for the current thread.
UPSTREAM-PARITY
xmlErrorPtr xmlCopyError(xmlErrorPtr from, xmlErrorPtr to);
Copies from into to. Returns 0 on success, -1 on error.
SAFETY
from and to must be valid pointers to _xmlError structs, or NULL.