pub unsafe fn dict_create_sub(parent: *mut Dict) -> *mut DictExpand description
Create a sub-dictionary that shares strings with its parent.
UPSTREAM-PARITY
xmlDictPtr xmlDictCreateSub(xmlDictPtr parent);A sub-dictionary uses the parent’s string table but maintains its own reference counts. Strings looked up in the sub-dictionary that exist in the parent are shared (the sub-dictionary increments the refcount).
Returns a pointer to the newly created sub-dictionary, or NULL on failure.
SAFETY
parentmust be a valid pointer to a Dict, or NULL.