pub unsafe fn dict_exists(
dict: *mut Dict,
name: *const xmlChar,
len: c_int,
) -> *const xmlCharExpand description
Check if a string exists in the dictionary without adding it.
UPSTREAM-PARITY
const xmlChar *xmlDictExists(xmlDictPtr dict, const xmlChar *name, int len);Returns a pointer to the interned string if found, or NULL if not found.
SAFETY
dictmust be a valid pointer to a Dict, or NULL.namemust be a valid pointer to a null-terminated string (if len < 0) or a buffer of at leastlenbytes (if len >= 0).