Entity handling (24, 85 Phase 6).
General entities, parameter entities, external entities, entity substitution, entity references, security limits, recursive entities, expansion limits.
Constants
- XML_
ENTITY_ CONTENT_ DEPTH_ MAX - Maximum entity recursion depth.
- XML_
ENTITY_ CONTENT_ EXPANSION_ MAX - Maximum entity expansion size (in bytes).
Functions
- add_
entity ⚠ - Add an entity declaration to a DTD.
- check_
entity_ expansion_ limit - Check if entity expansion exceeds limits.
- check_
entity_ recursion_ depth - Check if entity recursion depth exceeds limits.
- copy_
entity ⚠ - Deep copy an entity declaration.
- encode_
entities_ ⚠reentrant - Encode special XML characters in a string for output.
- free_
entity ⚠ - Free an entity declaration.
- get_
entity ⚠ - Get a general entity by name.
- get_
entity_ ⚠content - Get the content of an entity as a string.
- get_
entity_ ⚠from_ dtd - Look up an entity in a DTD’s entity hash table (upstream
xmlGetDtdEntitycore). - get_
parameter_ ⚠entity - Get a parameter entity by name.
- is_
external_ entity - Check if an entity type is an external entity.
- is_
parameter_ entity - Check if an entity type is a parameter entity.
- is_
predefined_ entity - Check if an entity type is a predefined entity.
- string_
decode_ ⚠entities - Decode entity references in a string.