pub unsafe fn cleanup_parser()Expand description
Clean up the parser library.
Should be called when the library is no longer needed. Only performs actual cleanup when the reference count reaches zero.
SAFETY
Must not be called while other libxml2 functions are executing in any thread.