Function hash_free
Source pub unsafe fn hash_free(table: *mut HashTable, f: Option<xmlHashDeallocator>)
Free a hash table.
UPSTREAM-PARITY
void xmlHashFree(xmlHashTablePtr table, xmlHashDeallocator f);
Frees all entries and calls f on each payload to free it.
SAFETY
table must be a valid pointer to a HashTable, or NULL.
f may be NULL (no deallocation of payloads).