Function hash_scan_full
Source pub unsafe fn hash_scan_full(
table: *mut HashTable,
f: Option<xmlHashScannerFull>,
data: *mut c_void,
)
Scan all entries with a full scanner function (includes all keys).
UPSTREAM-PARITY
void xmlHashScanFull(xmlHashTablePtr table, xmlHashScannerFull f, void *data);
SAFETY
table must be a valid pointer to a HashTable, or NULL.
f must be a valid function pointer or NULL.
data may be NULL.