Function list_search
Source pub unsafe fn list_search(l: *mut List, data: *const c_void) -> *mut c_void
Search the list for data matching the given key.
UPSTREAM-PARITY
void *xmlListSearch(xmlListPtr l, void *data);
Uses the list’s comparator function. Returns the matching data, or NULL.
SAFETY
l must be a valid pointer to a List, or NULL.