Function xmlReaderForFile
Source #[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlReaderForFile(
filename: *const c_char,
encoding: *const c_char,
options: c_int,
) -> *mut XmlTextReader
Create a text reader for a file.
UPSTREAM-PARITY
xmlTextReaderPtr xmlReaderForFile(const char *filename, const char *encoding, int options);
Safety
filename must be a valid C string or NULL.
encoding must be a valid C string or NULL.