#[unsafe(no_mangle)]pub unsafe extern "C" fn xmlTextReaderConstName( reader: *mut XmlTextReader, ) -> *const xmlChar
Get a constant pointer to the name (no copy).
The returned pointer is valid only while the reader is alive and positioned on the same node.
const xmlChar *xmlTextReaderConstName(xmlTextReaderPtr reader);
reader must be a valid pointer or NULL.
reader