#[unsafe(no_mangle)]pub unsafe extern "C" fn xmlTextReaderConstValue( reader: *mut XmlTextReader, ) -> *const xmlChar
Get a constant pointer to the value (no copy).
The returned pointer is valid only while the reader is alive and positioned on the same node.
const xmlChar *xmlTextReaderConstValue(xmlTextReaderPtr reader);
reader must be a valid pointer or NULL.
reader