#[unsafe(no_mangle)]pub unsafe extern "C" fn xmlTextReaderGetParserLineNumber(
reader: *mut XmlTextReader,
) -> c_intExpand description
Return the parser line number of the current node.
UPSTREAM-PARITY
Upstream xmlTextReaderGetParserLineNumber returns the input stream’s
current line. The candidate records line per node during parsing, which
is equivalent for the read cursor.
int xmlTextReaderGetParserLineNumber(xmlTextReaderPtr reader);Returns the line number, or 0 when unavailable.
Safety
reader must be a valid pointer or NULL.