Function xmlTextReaderLookupNamespace
Source #[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlTextReaderLookupNamespace(
reader: *mut XmlTextReader,
prefix: *const xmlChar,
) -> *mut xmlChar
Look up a namespace by prefix.
Returns a newly allocated string with the namespace URI, or NULL.
UPSTREAM-PARITY
xmlChar *xmlTextReaderLookupNamespace(xmlTextReaderPtr reader, const xmlChar *prefix);
Safety
reader and prefix must be valid pointers or NULL.