#[unsafe(no_mangle)]pub unsafe extern "C" fn xmlTextReaderReadAttributeValue(
reader: *mut XmlTextReader,
) -> c_intExpand description
Read the value of an attribute as a text node (attribute-value mode).
UPSTREAM-PARITY
Upstream xmlTextReaderReadAttributeValue moves the reader so that the
value of the current attribute is available as a text node, returning 1
on success and 0 when already at the end. The candidate tree stores
attribute values directly on the attribute node, so the value is already
available via xmlTextReaderValue; report 1 when positioned on an
attribute with a value.
int xmlTextReaderReadAttributeValue(xmlTextReaderPtr reader);Safety
reader must be a valid pointer or NULL.