xmlRegExecPushString

Function xmlRegExecPushString 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn xmlRegExecPushString( ctxt: *mut RegExecCtxt, value: *const xmlChar, ) -> c_int
Push a string into the incremental regex execution context.

UPSTREAM-PARITY

int xmlRegExecPushString(xmlRegExecCtxtPtr ctxt, const xmlChar *value);

Returns 1 if the pushed data completes a match, 0 if more data is needed, -1 on error.

SAFETY

  • ctxt must be a valid pointer to a RegExecCtxt, or NULL.
  • value must be a valid null-terminated xmlChar string, or NULL.