#[unsafe(no_mangle)]pub unsafe extern "C" fn xmlSchematronValidateDoc(
ctxt: *mut c_void,
doc: *mut _xmlDoc,
) -> c_intExpand description
Validate a document against a Schematron schema.
UPSTREAM-PARITY
int xmlSchematronValidateDoc(xmlSchematronValidCtxtPtr ctxt, xmlDocPtr doc);Returns 0 if valid, -1 on internal error, or the number of validation errors.
SAFETY
ctxtmust be a valid pointer to a validation context, or NULL.docmust be a valid pointer to an _xmlDoc, or NULL.