Function add_sibling
Source pub unsafe fn add_sibling(
cur: *mut _xmlNode,
elem: *mut _xmlNode,
) -> *mut _xmlNode
Add a sibling node after another.
UPSTREAM-PARITY
xmlNodePtr xmlAddSibling(xmlNodePtr cur, xmlNodePtr elem);
Adds elem as the next sibling of cur.
Returns elem, or NULL on failure.
SAFETY
cur must be a valid pointer to an _xmlNode.
elem must be a valid pointer to an _xmlNode.