free_node_list

Function free_node_list 

pub unsafe fn free_node_list(node: *mut _xmlNode)
Free a linked list of nodes.

Frees all nodes in the list and their children recursively.

SAFETY

  • node must be a valid pointer to an _xmlNode, or NULL.