pub unsafe fn get_ns_list(
doc: *mut _xmlDoc,
node: *mut _xmlNode,
) -> *mut *mut _xmlNsExpand description
Get a list of namespaces in scope for a node.
UPSTREAM-PARITY
xmlNsPtr *xmlGetNsList(xmlDocPtr doc, xmlNodePtr node);Returns a NULL-terminated array of namespace pointers in scope, or NULL on failure.
SAFETY
docmust be a valid pointer to an _xmlDoc, or NULL.nodemust be a valid pointer to an _xmlNode, or NULL.