Function set_ns
Source pub unsafe fn set_ns(node: *mut _xmlNode, ns: *mut _xmlNs)
Set the namespace of a node.
UPSTREAM-PARITY
void xmlSetNs(xmlNodePtr node, xmlNsPtr ns);
SAFETY
node must be a valid pointer to an _xmlNode, or NULL.
ns must be a valid pointer to an _xmlNs, or NULL.