pub unsafe fn set_prop(
node: *mut _xmlNode,
name: *const xmlChar,
value: *const xmlChar,
) -> *mut _xmlAttrExpand description
Set an attribute on a node.
UPSTREAM-PARITY
xmlAttrPtr xmlSetProp(xmlNodePtr node, const xmlChar *name, const xmlChar *value);Sets the attribute with the given name to the given value. If the attribute already exists, its value is updated. Creates the attribute if it doesn’t exist.
Returns the attribute pointer, or NULL on failure.
SAFETY
nodemust be a valid pointer to an _xmlNode, or NULL.namemust be a valid null-terminated string.valuemust be a valid null-terminated string or NULL.